=======================================
swb - Calculation of soil water balance
=======================================


.. image:: https://img.shields.io/pypi/v/swb.svg
        :target: https://pypi.python.org/pypi/swb

.. image:: https://img.shields.io/travis/openmeteo/swb.svg
        :target: https://travis-ci.org/openmeteo/swb

.. image:: https://codecov.io/github/openmeteo/swb/coverage.svg
        :target: https://codecov.io/gh/openmeteo/swb
        :alt: Coverage

.. image:: https://pyup.io/repos/github/openmeteo/swb/shield.svg
         :target: https://pyup.io/repos/github/openmeteo/swb/
         :alt: Updates


Model for calculation of soil water balance. See https://swb.readthedocs.io.
